@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2005  Bastian Kleineidam
+# Copyright (C) 2000-2007 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -45,48 +45,6 @@ class HtmlPrinter (object):
         """
         print >> self.fd, self.mem, attrs
 
-    def _errorfun (self, msg, name):
-        """
-        Print message to stderr with name prefix.
-
-        @param msg: message to print
-        @type msg: string
-        @param name: print this before the message
-        @type name: string
-        @return: None
-        """
-        print >> sys.stderr, name, msg
-
-    def error (self, msg):
-        """
-        Report filter/parser error.
-
-        @param msg: message to print
-        @type msg: string
-        @return: None
-        """
-        self._errorfun(msg, "error:")
-
-    def warning (self, msg):
-        """
-        Report a filter/parser warning.
-
-        @param msg: message to print
-        @type msg: string
-        @return: None
-        """
-        self._errorfun(msg, "warning:")
-
-    def fatal_error (self, msg):
-        """
-        Report a fatal filter/parser error.
-
-        @param msg: message to print
-        @type msg: string
-        @return: None
-        """
-        self._errorfun(msg, "fatal error:")
-
     def __getattr__ (self, name):
         """
         Remember the called method name in self.mem.
@@ -103,6 +61,7 @@ class HtmlPrinter (object):
 class HtmlPrettyPrinter (object):
     """
     Print out all parsed HTML data in encoded form.
+    Also stores error and warnings messages.
     """
 
     def __init__ (self, fd=sys.stdout, encoding="iso8859-1"):
@@ -172,7 +131,7 @@ class HtmlPrettyPrinter (object):
                 self.fd.write(" %s" % key)
             else:
                 val = val.encode(self.encoding, "ignore")
-                self.fd.write(" %s=\"%s\"" % (key, quote_attrval(val)))
+                self.fd.write(' %s="%s"' % (key, quote_attrval(val)))
         self.fd.write(end)
 
     def end_element (self, tag):
@@ -240,13 +199,16 @@ def quote_attrval (s):
     @return: the quoted HTML attribute
     @rtype: string
     """
-    s = s.replace('&', "&amp;")
-    s = s.replace('"', "&quot;")
-    return s
-
-
-def quote_val (s):
-    s = s.replace('&', "&amp;")
-    s = s.replace('<', "&lt;")
-    s = s.replace('>', "&gt;")
-    return s
+    res = []
+    for c in s:
+        if ord(c) <= 127:
+            # ASCII
+            if c == u'&':
+                res.append(u"&amp;")
+            elif c == u'"':
+                res.append(u"&quot;")
+            else:
+                res.append(c)
+        else:
+            res.append(u"&#%d;" % ord(c))
+    return u"".join(res)
