@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2006 Bastian Kleineidam
+# Copyright (C) 2000-2007 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,7 +26,6 @@ import urllib
 import urllib2
 
 import urlbase
-import linkcheck
 import linkcheck.log
 import linkcheck.checker
 import linkcheck.fileutil
@@ -146,9 +145,10 @@ class FileUrl (urlbase.UrlBase):
         path = self.get_os_filename()
         realpath = get_nt_filename(path)
         if path != realpath:
-            self.add_warning(_("The URL path %r is not the same as the "
-                               "system path %r. You should always use "
-                               "the system path in URLs.") % (path, realpath),
+            self.add_warning(_("The URL path %(path)r is not the same as the "
+                            "system path %(realpath)r. You should always use "
+                            "the system path in URLs.") % \
+                            {"path": path, "realpath": realpath},
                                tag="file-system-path")
 
     def get_content (self):
