@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2005  Bastian Kleineidam
+# Copyright (C) 2000-2007 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,7 +23,6 @@ import urllib
 import smtplib
 import email.Utils
 
-import linkcheck
 import urlbase
 import linkcheck.log
 import linkcheck.dns.resolver
@@ -47,7 +46,7 @@ def _split_address (address):
         return tuple(split)
     if len(split) == 1:
         return (split[0], "localhost")
-    raise linkcheck.LinkCheckerError, _("Could not split the mail address")
+    raise linkcheck.LinkCheckerError(_("Could not split the mail address"))
 
 
 class MailtoUrl (urlbase.UrlBase):
@@ -72,9 +71,9 @@ class MailtoUrl (urlbase.UrlBase):
         for name, addr in self.addresses:
             username, domain = _split_address(addr)
             if not linkcheck.url.is_safe_domain(domain):
-                raise linkcheck.LinkCheckerError, _("Invalid mail syntax")
-        linkcheck.log.debug(linkcheck.LOG_CHECK, "addresses: %s",
-                            self.addresses)
+                raise linkcheck.LinkCheckerError(_("Invalid mail syntax"))
+        assert None == linkcheck.log.debug(linkcheck.LOG_CHECK,
+            "addresses: %s", self.addresses)
 
     def cutout_addresses (self):
         """
@@ -109,9 +108,8 @@ class MailtoUrl (urlbase.UrlBase):
         if i < (len(url) - 1):
             try:
                 headers = cgi.parse_qs(url[(i+1):], strict_parsing=True)
-                for key, val in headers.items():
-                    key = key.lower()
-                    self.headers.setdefault(key, []).extend(val)
+                for key, val in headers.iteritems():
+                    self.headers.setdefault(key.lower(), []).extend(val)
             except ValueError, err:
                 self.add_warning(_("Error parsing CGI values: %s") % str(err))
             addrs = url[:i]
@@ -147,20 +145,21 @@ class MailtoUrl (urlbase.UrlBase):
         """
         Check a single mail address.
         """
-        linkcheck.log.debug(linkcheck.LOG_CHECK,
-                            "checking mail address %r", mail)
-        linkcheck.log.debug(linkcheck.LOG_CHECK, "splitting address")
+        assert None == linkcheck.log.debug(linkcheck.LOG_CHECK,
+            "checking mail address %r", mail)
+        assert None == linkcheck.log.debug(linkcheck.LOG_CHECK,
+            "splitting address")
         username, domain = _split_address(mail)
-        linkcheck.log.debug(linkcheck.LOG_CHECK,
-                            "looking up MX mailhost %r", domain)
+        assert None == linkcheck.log.debug(linkcheck.LOG_CHECK,
+            "looking up MX mailhost %r", domain)
         answers = linkcheck.dns.resolver.query(domain, 'MX')
         if len(answers) == 0:
-            self.add_warning(_("No MX mail host for %(domain)s found.") % \
+            self.add_warning(_("No MX mail host for %(domain)s found.") %
                             {'domain': domain},
                              tag="mail-no-mx-host")
             answers = linkcheck.dns.resolver.query(domain, 'A')
             if len(answers) == 0:
-                self.set_result(_("No host for %(domain)s found.") % \
+                self.set_result(_("No host for %(domain)s found.") %
                                  {'domain': domain}, valid=False)
                 return
             # set preference to zero
@@ -174,11 +173,11 @@ class MailtoUrl (urlbase.UrlBase):
             # host should be preferred)
             mxdata.sort()
         # debug output
-        linkcheck.log.debug(linkcheck.LOG_CHECK,
-                            "found %d MX mailhosts:", len(answers))
+        assert None == linkcheck.log.debug(linkcheck.LOG_CHECK,
+            "found %d MX mailhosts:", len(answers))
         for preference, host in mxdata:
-            linkcheck.log.debug(linkcheck.LOG_CHECK,
-                                "MX host %r, preference %d", host, preference)
+            assert None == linkcheck.log.debug(linkcheck.LOG_CHECK,
+                "MX host %r, preference %d", host, preference)
         # connect
         self.check_smtp_connect(mxdata, username, domain)
 
@@ -194,32 +193,33 @@ class MailtoUrl (urlbase.UrlBase):
         smtpconnect = 0
         for preference, host in mxdata:
             try:
-                linkcheck.log.debug(linkcheck.LOG_CHECK,
-                        "SMTP check for %r (preference %d)", host, preference)
+                assert None == linkcheck.log.debug(linkcheck.LOG_CHECK,
+                    "SMTP check for %r (preference %d)", host, preference)
                 self.url_connection = smtplib.SMTP()
                 if linkcheck.log.is_debug(linkcheck.LOG_CHECK):
                     self.url_connection.set_debuglevel(1)
                 self.url_connection.connect(host)
-                linkcheck.log.debug(linkcheck.LOG_CHECK, "SMTP connected!")
+                assert None == linkcheck.log.debug(linkcheck.LOG_CHECK,
+                    "SMTP connected!")
                 smtpconnect = 1
                 self.url_connection.helo()
                 info = self.url_connection.verify("%s@%s" % (username, domain))
-                linkcheck.log.debug(linkcheck.LOG_CHECK,
-                                    "SMTP user info %r", info)
+                assert None == linkcheck.log.debug(linkcheck.LOG_CHECK,
+                    "SMTP user info %r", info)
                 d = {'info': str(info[1])}
                 if info[0] == 250:
                     self.add_info(_("Verified address: %(info)s.") % d)
                 # check for 25x return code which means that the address
                 # could not be verified, but is sent anyway
                 elif 0 < (info[0] - 250) < 10:
-                    self.add_info(_("Unverified address: %(info)s." \
+                    self.add_info(_("Unverified address: %(info)s."
                                   " But mail will be sent anyway.") % d)
                 else:
                     self.add_warning(_("Unverified address: %(info)s.") % d,
                      tag="mail-unverified-address")
             except smtplib.SMTPException, msg:
                 self.add_warning(
-                      _("MX mail host %(host)s did not accept connections: " \
+                      _("MX mail host %(host)s did not accept connections: "
                         "%(error)s.") % {'host': host, 'error': str(msg)},
                         tag="mail-no-connection")
             if smtpconnect:
