@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2005  Bastian Kleineidam
+# Copyright (C) 2000-2007 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ class NntpUrl (urlbase.UrlBase):
         Connect to NNTP server and try to request the URL article
         resource (if specified).
         """
-        nntpserver = self.host or self.consumer.config("nntpserver")
+        nntpserver = self.host or self.aggregate.config["nntpserver"]
         if not nntpserver:
             self.add_warning(
                     _("No NNTP server was specified, skipping this URL."),
@@ -85,8 +85,8 @@ class NntpUrl (urlbase.UrlBase):
                 else:
                     raise
         if nntp is None:
-            raise linkcheck.LinkCheckerError, \
-               _("NTTP server too busy; tried more than %d times.") % tries
+            raise linkcheck.LinkCheckerError(
+               _("NTTP server too busy; tried more than %d times.") % tries)
         if value is not None:
             self.add_warning(_("NNTP busy: %s.") % str(value),
                              tag="nttp-busy")
