@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2006 Bastian Kleineidam
+# Copyright (C) 2000-2007 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,7 +29,6 @@ import socket
 import select
 import traceback
 
-import linkcheck
 import linkcheck.linkparse
 import linkcheck.checker
 import linkcheck.cache.geoip
@@ -41,6 +40,8 @@ import linkcheck.log
 import linkcheck.httplib2
 import linkcheck.HtmlParser.htmlsax
 
+# helper alias
+unicode_safe = linkcheck.strformat.unicode_safe
 
 def urljoin (parent, url, scheme):
     """
@@ -295,8 +296,7 @@ class UrlBase (object):
                                  tag="url-effective-url")
                 self.url = effectiveurl
         except tuple(linkcheck.checker.ExcSyntaxList), msg:
-            self.set_result(linkcheck.strformat.unicode_safe(msg),
-                            valid=False)
+            self.set_result(unicode_safe(msg), valid=False)
             return
         self.set_cache_keys()
 
@@ -308,9 +308,10 @@ class UrlBase (object):
         # norm base url - can raise UnicodeError from url.idna_encode()
         base_url, is_idn = url_norm(self.base_url)
         if is_idn:
-            self.add_warning(_("""URL %r has a unicode domain name which
+            self.add_warning(_("""URL %(url)r has a unicode domain name which
                           is not yet widely supported. You should use
-                          the URL %r instead.""") % (self.base_url, base_url),
+                          the URL %(idna_url)r instead.""") % \
+                          {"url": self.base_url, "idna_url": base_url},
                           tag="url-unicode-domain")
         elif self.base_url != base_url:
             self.add_warning(
@@ -411,8 +412,7 @@ class UrlBase (object):
             # make nicer error msg for bad status line
             if isinstance(value, linkcheck.httplib2.BadStatusLine):
                 value = _('Bad HTTP response %r') % str(value)
-            self.set_result(linkcheck.strformat.unicode_safe(value),
-                            valid=False)
+            self.set_result(unicode_safe(value), valid=False)
 
         # check content
         warningregex = self.aggregate.config["warningregex"]
@@ -423,8 +423,7 @@ class UrlBase (object):
                 self.check_content(warningregex)
             except tuple(linkcheck.checker.ExcList):
                 value = self.handle_exception()
-                self.set_result(linkcheck.strformat.unicode_safe(value),
-                                valid=False)
+                self.set_result(unicode_safe(value), valid=False)
 
         self.checktime = time.time() - check_start
         # check recursion
@@ -621,9 +620,10 @@ class UrlBase (object):
         """
         maxbytes = self.aggregate.config["warnsizebytes"]
         if maxbytes is not None and self.dlsize >= maxbytes:
-            self.add_warning(_("Content size %s is larger than %s.") %
-                         (linkcheck.strformat.strsize(self.dlsize),
-                          linkcheck.strformat.strsize(maxbytes)),
+            self.add_warning(
+                   _("Content size %(dlsize)s is larger than %(maxbytes)s.") %
+                        {"dlsize": linkcheck.strformat.strsize(self.dlsize),
+                         "maxbytes": linkcheck.strformat.strsize(maxbytes)},
                           tag="url-content-too-large")
 
     def parse_url (self):
@@ -734,7 +734,7 @@ class UrlBase (object):
         """
         Return serialized url check data as unicode string.
         """
-        sep = linkcheck.strformat.unicode_safe(os.linesep)
+        sep = unicode_safe(os.linesep)
         if self.base_url is not None:
             assert isinstance(self.base_url, unicode), self
         if self.parent_url is not None:
