@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2006 Bastian Kleineidam
+# Copyright (C) 2000-2007 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -215,3 +215,14 @@ class Configuration (dict):
         assert None == linkcheck.log.debug(linkcheck.LOG_CHECK,
             "reading configuration from %s", cfiles)
         confparse.LCConfigParser(self).read(cfiles)
+        self.sanitize()
+
+    def sanitize (self):
+        "Make sure the configuration is consistent."
+        if self["anchors"]:
+            if not self["warnings"]:
+                self["warnings"] = True
+                self["ignorewarnings"] = linkcheck.checker.Warnings.keys()
+            if 'url-anchor-not-found' in self["ignorewarnings"]:
+                self["ignorewarnings"].remove('url-anchor-not-found')
+
