@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2006 Bastian Kleineidam
+# Copyright (C) 2000-2007 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,10 +18,9 @@
 
 import ConfigParser
 import re
-import linkcheck
 import linkcheck.log
 
-class LCConfigParser (ConfigParser.ConfigParser, object):
+class LCConfigParser (ConfigParser.RawConfigParser, object):
     """
     Parse a LinkChecker configuration file.
     """
@@ -148,7 +147,8 @@ class LCConfigParser (ConfigParser.ConfigParser, object):
                     self.config["warningregex"] = re.compile(arg)
                 except re.error, msg:
                     raise linkcheck.LinkCheckerError(linkcheck.LOG_CHECK,
-                       _("syntax error in warningregex %r: %s\n"), arg, msg)
+                   _("syntax error in warningregex %(regex)r: %(msg)s\n") % \
+                   {"regex": arg, "msg": msg})
         except ConfigParser.Error, msg:
             assert None == linkcheck.log.debug(linkcheck.LOG_CHECK, msg)
         try:
@@ -166,14 +166,34 @@ class LCConfigParser (ConfigParser.ConfigParser, object):
         except ConfigParser.Error, msg:
             assert None == linkcheck.log.debug(linkcheck.LOG_CHECK, msg)
         try:
-            i = 1
-            while 1:
-                arg = self.get(section, "noproxyfor%d" % i)
+            value = self.get(section, "noproxyfor")
+            for line in value.splitlines():
+                line = line.strip()
+                if not line or line.startswith('#'):
+                    continue
                 try:
                     arg = re.compile(arg)
                 except re.error, msg:
                     raise linkcheck.LinkCheckerError(linkcheck.LOG_CHECK,
-                       _("syntax error in noproxyfor%d %r: %s"), i, arg, msg)
+                   _("syntax error in noproxyfor %(line)r: %(msg)s") % \
+                    {"line": line, "msg": msg})
+                self.config["noproxyfor"].append(arg)
+        except ConfigParser.Error, msg:
+            assert None == linkcheck.log.debug(linkcheck.LOG_CHECK, msg)
+        try:
+            # XXX backward compatibility
+            i = 1
+            while 1:
+                arg = self.get(section, "noproxyfor%d" % i)
+                linkcheck.log.warn(linkcheck.LOG_CHECK,
+                  _("the noproxyfor%(num)d syntax is deprecated; use " \
+                    "the new multiline configuration syntax") % {"num": i})
+                try:
+                    arg = re.compile(arg)
+                except re.error, msg:
+                    raise linkcheck.LinkCheckerError(linkcheck.LOG_CHECK,
+                   _("syntax error in noproxyfor%(num)d %(arg)r: %(msg)s") % \
+                    {"num": i, "arg": arg, "msg": msg})
                 self.config["noproxyfor"].append(arg)
                 i += 1
         except ConfigParser.Error, msg:
@@ -190,16 +210,43 @@ class LCConfigParser (ConfigParser.ConfigParser, object):
         """
         section = "authentication"
         try:
+            arg = self.get(section, "entry")
+            for line in arg.splitlines():
+                line = line.strip()
+                if not line or line.startswith('#'):
+                    continue
+                auth = line.split()
+                if len(auth) != 3:
+                    raise linkcheck.LinkCheckerError(linkcheck.LOG_CHECK,
+                       _("missing auth part in entry %(line)r") % \
+                       {"line": line})
+                try:
+                    auth[0] = re.compile(auth[0])
+                except re.error, msg:
+                    raise linkcheck.LinkCheckerError(linkcheck.LOG_CHECK,
+                       _("syntax error in entry %(line)r: %(msg)s") % \
+                       {"line": line, "msg": msg})
+                self.config["authentication"].insert(0, {'pattern': auth[0],
+                                                  'user': auth[1],
+                                                  'password': auth[2]})
+        except ConfigParser.Error, msg:
+            assert None == linkcheck.log.debug(linkcheck.LOG_CHECK, msg)
+        try:
+            # XXX backward compatibility
             i = 1
             while 1:
                 auth = self.get(section, "entry%d" % i).split()
+                linkcheck.log.warn(linkcheck.LOG_CHECK,
+                  _("the entry%(num)d syntax is deprecated; use " \
+                    "the new multiline configuration syntax") % {"num": i})
                 if len(auth) != 3:
                     break
                 try:
                     auth[0] = re.compile(auth[0])
                 except re.error, msg:
                     raise linkcheck.LinkCheckerError(linkcheck.LOG_CHECK,
-                       _("syntax error in entry%d %r: %s"), i, auth[0], msg)
+                       _("syntax error in entry%(num)d %(arg)r: %(msg)s") % \
+                       {"num": i, "arg": auth[0], "msg": msg})
                 self.config["authentication"].insert(0, {'pattern': auth[0],
                                                   'user': auth[1],
                                                   'password': auth[2]})
@@ -213,9 +260,23 @@ class LCConfigParser (ConfigParser.ConfigParser, object):
         """
         section = "filtering"
         try:
+            arg = self.get(section, "nofollow")
+            for line in arg.splitlines():
+                line = line.strip()
+                if not line or line.startswith('#'):
+                    continue
+                pat = linkcheck.get_link_pat(line, strict=0)
+                self.config["externlinks"].append(pat)
+        except ConfigParser.Error, msg:
+            assert None == linkcheck.log.debug(linkcheck.LOG_CHECK, msg)
+        try:
+            # XXX backward compatibility
             i = 1
             while 1:
                 val = self.get(section, "nofollow%d" % i)
+                linkcheck.log.warn(linkcheck.LOG_CHECK,
+                  _("the nofollow%(num)d syntax is deprecated; use " \
+                    "the new multiline configuration syntax") % {"num": i})
                 pat = linkcheck.get_link_pat(val, strict=0)
                 self.config["externlinks"].append(pat)
                 i += 1
@@ -227,10 +288,24 @@ class LCConfigParser (ConfigParser.ConfigParser, object):
         except ConfigParser.Error, msg:
             assert None == linkcheck.log.debug(linkcheck.LOG_CHECK, msg)
         try:
+            arg = self.get(section, "ignore")
+            for line in arg.splitlines():
+                line = line.strip()
+                if not line or line.startswith('#'):
+                    continue
+                pat = linkcheck.get_link_pat(line, strict=1)
+                self.config["externlinks"].append(pat)
+        except ConfigParser.Error, msg:
+            assert None == linkcheck.log.debug(linkcheck.LOG_CHECK, msg)
+        try:
+            # XXX backward compatibility
             i = 1
             while 1:
                 # XXX backwards compatibility: split and ignore second part
                 val = self.get(section, "ignore%d" % i).split()[0]
+                linkcheck.log.warn(linkcheck.LOG_CHECK,
+                  _("the ignore%(num)d syntax is deprecated; use " \
+                    "the new multiline configuration syntax") % {"num": i})
                 pat = linkcheck.get_link_pat(val, strict=1)
                 self.config["externlinks"].append(pat)
                 i += 1
