@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2006 Bastian Kleineidam
+# Copyright (C) 2006-2007 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,8 +18,7 @@
 Management of checking a queue of links with several threads.
 """
 import time
-import signal
-import linkcheck
+import thread
 import linkcheck.log
 import linkcheck.cache.urlqueue
 import linkcheck.cache.robots_txt
@@ -39,32 +38,77 @@ def check_urls (aggregate):
         aggregate.logger.start_log_output()
         if not aggregate.urlqueue.empty():
             aggregate.start_threads()
-        # Since urlqueue.join() is not interruptable, add a timeout
-        # and a one-second slumber.
-        while True:
-            try:
-                aggregate.urlqueue.join(timeout=1)
-                break
-            except linkcheck.cache.urlqueue.Timeout:
-                time.sleep(1)
-                aggregate.remove_stopped_threads()
-                if not aggregate.threads:
-                    break
-                sigint = signal.getsignal(signal.SIGINT)
-                if sigint != signal.default_int_handler:
-                    linkcheck.log.warn(linkcheck.LOG_CHECK,
-                      _("signal interrupt handler changed to %s"), sigint)
+        check_url(aggregate)
+        aggregate.finish()
+        aggregate.logger.end_log_output()
     except KeyboardInterrupt:
+        interrupt(aggregate)
+    except thread.error:
         linkcheck.log.warn(linkcheck.LOG_CHECK,
-            _("keyboard interrupt; waiting for active threads to finish"))
-        aggregate.abort()
+             _("Could not start a new thread. Check that the current user" \
+               " is allowed to start new threads."))
+        abort(aggregate)
     except:
         console.internal_error()
-        aggregate.abort()
-    aggregate.finish()
-    aggregate.logger.end_log_output()
+        abort(aggregate)
 
 
+def check_url (aggregate):
+    """
+    Helper function waiting for URL queue.
+    """
+    while True:
+        try:
+            aggregate.urlqueue.join(timeout=1)
+            break
+        except linkcheck.cache.urlqueue.Timeout:
+            # Since urlqueue.join() is not interruptable, add a timeout
+            # and a one-second slumber.
+            time.sleep(1)
+            aggregate.remove_stopped_threads()
+            if not aggregate.threads:
+                break
+
+
+def interrupt (aggregate):
+    """
+    Interrupt execution and shutdown, ignoring any subsequent interrupts.
+    """
+    while True:
+        try:
+            linkcheck.log.warn(linkcheck.LOG_CHECK,
+               _("keyboard interrupt; waiting for active threads to finish"))
+            print_active_threads(aggregate)
+            abort(aggregate)
+            break
+        except KeyboardInterrupt:
+            pass
+
+
+def print_active_threads (aggregate):
+    if not aggregate.threads:
+        return
+    linkcheck.log.info(linkcheck.LOG_CHECK, _("These URLs are still active:"))
+    for t in aggregate.threads:
+        name = t.getName()
+        if name.startswith("Check-"):
+            linkcheck.log.info(linkcheck.LOG_CHECK, name[6:])
+
+
+def abort (aggregate):
+    """
+    Helper function to ensure a clean shutdown.
+    """
+    while True:
+        try:
+            aggregate.abort()
+            aggregate.finish()
+            aggregate.logger.end_log_output()
+            break
+        except KeyboardInterrupt:
+            linkcheck.log.warn(linkcheck.LOG_CHECK, _("shutdown in progress"))
+            print_active_threads(aggregate)
+
 def get_aggregate (config):
     """
     Get an aggregator instance with given configuration.
