@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2006 Bastian Kleineidam
+# Copyright (C) 2006-2007 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -77,7 +77,7 @@ class Checker (task.CheckedTask):
                 url = ""
             else:
                 url = url_data.url.encode("ascii", "replace")
-            self.setName("Thread-%s" % url)
+            self.setName("Check-%s" % url)
             if not url_data.has_result:
                 url_data.check()
             self.logger.log_url(url_data)
