@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2006 Bastian Kleineidam
+# Copyright (C) 2000-2007 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,7 +25,6 @@ import time
 import urlparse
 import types
 
-import linkcheck
 import linkcheck.configuration
 import linkcheck.url
 import linkcheck.i18n
@@ -35,7 +34,7 @@ import linkcheck.director
 
 _logfile = None
 _supported_langs = ('de', 'fr', 'nl', 'C')
-_is_level = re.compile(r'^[0123]$').match
+_is_level = re.compile(r'^(0|1|2|3|-1)$').match
 
 class FormError (StandardError):
     """
