@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2006 Bastian Kleineidam
+# Copyright (C) 2000-2007 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -41,13 +41,12 @@ HTML_HEADER = """<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
 <title>%s</title>
 <style type="text/css">
 <!--
- h2 { font-family: Verdana,sans-serif; font-size: 22pt;
- font-style: bold; font-weight: bold }
+ h2 { font-family: Verdana,sans-serif; font-size: 22pt; font-weight: bold }
  body { font-family: Arial,sans-serif; font-size: 11pt }
  td { font-family: Arial,sans-serif; font-size: 11pt }
  code { font-family: Courier }
  a:hover { color: #34a4ef }
- //-->
+-->
 </style>
 </head>
 <body bgcolor="%s" link="%s" vlink="%s" alink="%s">
@@ -91,12 +90,11 @@ class HtmlLogger (linkcheck.logger.Logger):
         Write start of checking info.
         """
         super(HtmlLogger, self).start_output()
-        if self.fd is None:
-            return
         self.starttime = time.time()
         self.write(HTML_HEADER % (linkcheck.configuration.App,
                    self.colorbackground,
                    self.colorlink, self.colorlink, self.colorlink))
+        self.comment("Generated by %s" % linkcheck.configuration.App)
         if self.has_part('intro'):
             self.write(u"<center><h2>"+linkcheck.configuration.App+
                        "</h2></center><br><blockquote>"+
@@ -111,8 +109,6 @@ class HtmlLogger (linkcheck.logger.Logger):
         """
         Write url checking info as HTML.
         """
-        if self.fd is None:
-            return
         self.write_table_start()
         if self.has_part("url"):
             self.write_url(url_data)
@@ -168,7 +164,7 @@ class HtmlLogger (linkcheck.logger.Logger):
         self.writeln(u'<td bgcolor="%s">%s</td>' %
                      (self.colorurl, self.part("url")))
         self.write(u'<td bgcolor="%s">' % self.colorurl)
-        self.write(u"%s" % cgi.escape(repr(url_data.base_url or u"")[1:]))
+        self.write(u"`%s'" % cgi.escape(url_data.base_url or u""))
         if url_data.cached:
             self.write(_(" (cached)"))
         self.writeln(u"</td></tr>")
@@ -177,8 +173,8 @@ class HtmlLogger (linkcheck.logger.Logger):
         """
         Write url_data.name.
         """
-        self.writeln(u"<tr><td>" + self.part("name") + u"</td><td>" +
-                     cgi.escape(repr(url_data.name)[1:]) + u"</td></tr>")
+        args = (self.part("name"), cgi.escape(url_data.name))
+        self.writeln(u"<tr><td>%s</td><td>`%s'</td></tr>" % args)
 
     def write_parent (self, url_data):
         """
@@ -280,8 +276,6 @@ class HtmlLogger (linkcheck.logger.Logger):
         """
         Write end of checking info as HTML.
         """
-        if self.fd is None:
-            return
         if self.has_part("outro"):
             self.writeln()
             self.write(_("That's it.")+" ")
@@ -297,9 +291,9 @@ class HtmlLogger (linkcheck.logger.Logger):
             self.writeln(u"<br>")
             self.stoptime = time.time()
             duration = self.stoptime - self.starttime
-            self.writeln(_("Stopped checking at %s (%s)") %
-                         (linkcheck.strformat.strtime(self.stoptime),
-                          linkcheck.strformat.strduration_long(duration)))
+            self.writeln(_("Stopped checking at %(time)s (%(duration)s)") %
+                 {"time": linkcheck.strformat.strtime(self.stoptime),
+                  "duration": linkcheck.strformat.strduration_long(duration)})
             self.writeln(u'</blockquote><br><hr noshade size="1"><small>'+
                          linkcheck.configuration.HtmlAppInfo+u"<br>")
             self.writeln(_("Get the newest version at %s") %
