@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2000-2005  Bastian Kleineidam
+# Copyright (C) 2000-2007 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@ import os
 import urlparse
 import urllib
 
-urlparse.uses_netloc.append('ldap')
+urlparse.uses_netloc.extend(('ldap', 'irc'))
 
 # constants defining url part indexes
 SCHEME = 0
@@ -51,7 +51,7 @@ _safe_char = r"([%(_az09)s%(_path)s\+]|"\
 _safe_scheme_pattern = r"(https?|ftp)"
 _safe_domain_pattern = r"([%(_az09)s][%(_az09)s\-]*"\
                        r"(\.[%(_az09)s][%(_az09)s\-]*)*\.?)" % _basic
-_safe_host_pattern = _safe_domain_pattern+r"(:(80|8080|8000))?" % _basic
+_safe_host_pattern = _safe_domain_pattern+r"(:(80|8080|8000|443))?" % _basic
 _safe_path_pattern = r"((/([%(_az09)s%(_path)s]|"\
                      r"(%%[%(_hex_safe)s][%(_hex_full)s]))+)*/?)" % _basic
 _safe_fragment_pattern = r"%s*" % _safe_char
@@ -78,7 +78,7 @@ def splitparams (path):
     Split off parameter part from path.
     Returns tuple (path-without-param, param)
     """
-    if '/'  in path:
+    if '/' in path:
         i = path.find(';', path.rfind('/'))
     else:
         i = path.find(';')
@@ -87,36 +87,16 @@ def splitparams (path):
     return path[:i], path[i+1:]
 
 
-def is_safe_js_url (urlstr):
-    """
-    Test javascript URL strings.
-    """
-    url = list(urlparse.urlsplit(urlstr))
-    if url[0].lower() != 'http':
-        return False
-    if not is_safe_host(url[1]):
-        return False
-    if ";" in urlstr:
-        url[2], parameter = splitparams(url[2])
-        if not is_safe_parameter(parameter):
-            return False
-    if not is_safe_path(url[2]):
-        return False
-    if not is_safe_query(url[3]):
-        return False
-    if not is_safe_fragment(url[4]):
-        return False
-    return True
-
-
 def is_numeric_port (portstr):
     """
-    return True iff portstr is a valid port number
+    return: integer port (== True) iff portstr is a valid port number,
+           False otherwise
     """
     if portstr.isdigit():
         port = int(portstr)
         # 65536 == 2**16
-        return 0 < port < 65536
+        if 0 < port < 65536:
+            return port
     return False
 
 
@@ -172,7 +152,7 @@ def parse_qsl (qs, keep_blank_values=0, strict_parsing=0):
         nv = name_value.split('=', 1)
         if len(nv) != 2:
             if strict_parsing:
-                raise ValueError, "bad query field: %s" % `name_value`
+                raise ValueError("bad query field: %s" % `name_value`)
             elif len(nv) == 1:
                 # None value indicates missing equal sign
                 nv = (nv[0], None)
@@ -232,18 +212,15 @@ def url_fix_host (urlparts):
             userpass += "@"
         else:
             userpass = ""
-        newhost, port = urllib.splitnport(host)
-        if port is not None:
-            host = newhost
-        # remove trailing dot
-        if host.endswith("."):
-            host = host[:-1]
-        # remove a default (or invalid) port
-        if port in [-1, None, default_ports.get(urlparts[0])]:
-            urlparts[1] = userpass+host
-        else:
-            urlparts[1] = "%s%s:%d" % (userpass, host, port)
-
+        if urlparts[0] in default_ports:
+            dport = default_ports[urlparts[0]]
+            host, port = splitport(host, port=dport)
+            if host.endswith("."):
+                host = host[:-1]
+            if port != dport:
+                host = "%s:%d" % (host, port)
+        urlparts[1] = userpass+host
+    return is_idn
 
 def url_fix_common_typos (url):
     """
@@ -268,6 +245,8 @@ def url_parse_query (query):
     """
     Parse and re-join the given CGI query.
     """
+    if isinstance(query, unicode):
+        query = query.encode('iso8859-1', 'ignore')
     # if ? is in the query, split it off, seen at msdn.microsoft.com
     if '?' in query:
         query, append = query.split('?', 1)
@@ -276,9 +255,9 @@ def url_parse_query (query):
         append = ""
     l = []
     for k, v, sep in parse_qsl(query, True):
-        k = url_quote_part(k, '/-:,;')
+        k = url_quote_part(k, '/-:,; ').replace(' ', '+')
         if v:
-            v = url_quote_part(v, '/-:,;')
+            v = url_quote_part(v, '-:,; ').replace(' ', '+')
             l.append("%s=%s%s" % (k, v, sep))
         elif v is None:
             l.append("%s%s" % (k, sep))
@@ -476,5 +455,29 @@ def url_split (url):
     port = default_ports.get(scheme, 80)
     if host:
         host = host.lower()
-        host, port = urllib.splitnport(host, port)
+        host, port = splitport(host, port=port)
     return scheme, host, port, document
+
+
+def url_unsplit (parts):
+    if parts[2] == default_ports.get(parts[0]):
+        return "%s://%s%s" % (parts[0], parts[1], parts[3])
+    return "%s://%s:%d%s" % parts
+
+
+def splitport (host, port=80):
+    """
+    Split optional port number from host. If host has no port number,
+    the given default port is returned.
+
+    @param host: host name
+    @ptype host: string
+    @return: tuple of (host, port)
+    @rtype: tuple of (string, int)
+    """
+    if ":" in host:
+        host, sport = host.split(":", 1)
+        iport = is_numeric_port(sport)
+        if iport:
+            port = iport
+    return host, port
